package scws;

public abstract class AbstractUnit<T extends AbstractUnit<T>> implements Comparable<T> {
	private static final double EPS = 1e-10;

	protected final double units;

	protected AbstractUnit(double units) {
		this.units = units;
	}

	public abstract T neg();
	public abstract T abs();
	public abstract T add(T rhs);
	public abstract T sub(T rhs);
	public abstract T mul(double scalar);
	public abstract T div(double scalar);

	public abstract double as(String unit) throws InvalidUnitException;

	@Override
	public int compareTo(T rhs) {
		return (this.units - rhs.units < EPS) ? 0 : (this.units < rhs.units) ? -1 : 1;
	}
	@Override
	public int hashCode() {
		return (int)Math.round(units);
	}
	@Override
	public boolean equals(Object rhs) {
		return this.getClass().isInstance(rhs) && (Math.abs(this.units - ((AbstractUnit<?>)rhs).units) < EPS);
	}
}
