package scws;

public class Length extends AbstractUnit<Length> {
	private static final double cm =    1.00;
	private static final double in =    2.54;
	private static final double ft =   12.00 * in;
	private static final double yd =    3.00 * ft;
	private static final double m  =  100.00 * cm;
	private static final double km = 1000.00 *  m;
	private static final double mi = 1760.00 * yd;
	private static final double nm = 1852.00 *  m;

	public static final Length ZERO = new Length(0.0);
	
	private Length(double units) {
		super(units);
	}
	public Length(double value, String unit) throws InvalidUnitException {
		super(value * getBase(unit));
	}
	private static double getBase(String unit) throws InvalidUnitException {
		switch(unit) {
		case "cm" : return cm;
		case "in" : return in;
		case "ft" : return ft;
		case "yd" : return yd;
		case "m"  : return m;
		case "km" : return km;
		case "mi" : return mi;
		case "nm" : return nm;
		}
	    throw new InvalidUnitException(unit);
	}
	@Override
	public Length neg() {
		return new Length(-this.units);
	}
	@Override
	public Length abs() {
		return new Length((this.units < 0) ? -this.units : this.units);
	}
	@Override
	public Length add(Length len) {
		return new Length(this.units + len.units);
	}
	@Override
	public Length sub(Length len) {
		return new Length(this.units - len.units);
	}
	@Override
	public Length mul(double scalar) {
		return new Length(this.units * scalar);
	}
	@Override
	public Length div(double scalar) {
		return new Length(this.units / scalar);
	}
	public Speed div(Time time) throws InvalidUnitException {
		return new Speed(this.as("m") / time.as("s"), "m/s");
	}
	public Time div(Speed speed) throws InvalidUnitException {
		return new Time(this.as("mi") / speed.as("m/s"), "s");
	}
	@Override
	public String toString() {
		return Double.toString(this.units / cm) + "cm"; 
	}
	@Override
	public double as(String unit) throws InvalidUnitException {
		return this.units / getBase(unit);
	}
}
