package scws;

public class Mass extends AbstractUnit<Mass> {
	private static final double g  =    1.00000;
	private static final double kg = 1000.00000 * g;
	private static final double t  = 1000.00000 * kg;
	private static final double oz =   28.34952 * g;
	private static final double lb =   16.00000 * oz;

	public static final Mass ZERO = new Mass(0.0);
	
	private Mass(double units) {
		super(units);
	}
	public Mass(double value, String unit) throws InvalidUnitException {
		super(value * getBase(unit));
	}
	private static double getBase(String unit) throws InvalidUnitException {
		switch(unit) {
		case "g"  : return g;
		case "oz" : return oz;
		case "lb" : return lb;
		case "kg" : return kg;
		case "t"  : return t;
		}
	    throw new InvalidUnitException(unit);
	}
	@Override
	public Mass neg() {
		return new Mass(-this.units);
	}
	@Override
	public Mass abs() {
		return new Mass((this.units < 0) ? -this.units : this.units);
	}
	@Override
	public Mass add(Mass mass) {
		return new Mass(this.units + mass.units);
	}
	@Override
	public Mass sub(Mass mass) {
		return new Mass(this.units - mass.units);
	}
	@Override
	public Mass mul(double scalar) {
		return new Mass(this.units * scalar);
	}
	@Override
	public Mass div(double scalar) {
		return new Mass(this.units / scalar);
	}
	@Override
	public String toString() {
		return Double.toString(this.units / kg) + "kg"; 
	}
	@Override
	public double as(String unit) throws InvalidUnitException {
		return this.units / getBase(unit);
	}
}
