package scws;

public class Speed extends AbstractUnit<Speed> {
	private static final double mps  =  1.000000;
	private static final double kmph =  mps  / 3.600000;
	private static final double miph =  kmph * 1.609344;
	private static final double knot =  kmph * 1.852000;

	public static final Speed ZERO = new Speed(0.0);
	
	private Speed(double units) {
		super(units);
	}
	public Speed(double value, String unit) throws InvalidUnitException {
		super(value * getBase(unit));
	}
	private static double getBase(String unit) throws InvalidUnitException {
		switch(unit) {
		case "m/s"  : return mps;
		case "km/h" : return kmph;
		case "mi/h" : return miph;
		case "knot" : return knot;
		}
	    throw new InvalidUnitException(unit);
	}
	@Override
	public Speed neg() {
		return new Speed(-this.units);
	}
	@Override
	public Speed abs() {
		return new Speed((this.units < 0) ? -this.units : this.units);
	}
	@Override
	public Speed add(Speed speed) {
		return new Speed(this.units + speed.units);
	}
	@Override
	public Speed sub(Speed speed) {
		return new Speed(this.units - speed.units);
	}
	@Override
	public Speed mul(double scalar) {
		return new Speed(this.units * scalar);
	}
	@Override
	public Speed div(double scalar) {
		return new Speed(this.units / scalar);
	}
	public Length mul(Time time) throws InvalidUnitException {
		return new Length(this.as("m/s") * time.as("s"), "m");
	}
	@Override
	public String toString() {
		return Double.toString(this.units / mps) + "m/s"; 
	}
	@Override
	public double as(String unit) throws InvalidUnitException {
		return this.units / getBase(unit);
	}
}
