package scws;

public class Time extends AbstractUnit<Time> {
	private static final double s =  1.0;
	private static final double m = 60.0 * s;
	private static final double h = 60.0 * m;

	public static final Time ZERO = new Time(0.0);
	
	private Time(double units) {
		super(units);
	}
	public Time(double value, String unit) throws InvalidUnitException {
		super(value * getBase(unit));
	}
	private static double getBase(String unit) throws InvalidUnitException {
		switch(unit) {
		case "s" : return s;
		case "m" : return m;
		case "h" : return h;
		}
	    throw new InvalidUnitException(unit);
	}
	@Override
	public Time neg() {
		return new Time(-this.units);
	}
	@Override
	public Time abs() {
		return new Time((this.units < 0) ? -this.units : this.units);
	}
	@Override
	public Time add(Time time) {
		return new Time(this.units + time.units);
	}
	@Override
	public Time sub(Time time) {
		return new Time(this.units - time.units);
	}
	@Override
	public Time mul(double scalar) {
		return new Time(this.units * scalar);
	}
	@Override
	public Time div(double scalar) {
		return new Time(this.units / scalar);
	}
	@Override
	public String toString() {
		return Double.toString(this.units / s) + "s"; 
	}
	@Override
	public double as(String unit) throws InvalidUnitException {
		return this.units / getBase(unit);
	}
}
